summaryrefslogtreecommitdiff
path: root/framework/Web/UI
diff options
context:
space:
mode:
authorwei <>2006-09-10 01:03:56 +0000
committerwei <>2006-09-10 01:03:56 +0000
commitf1f33db1f85c0893205a4a00c203d884dc1af1a5 (patch)
treede0fd5a1b52572708209c98370c9061a19ec5193 /framework/Web/UI
parentfa760c403236b6fe7fdfd5785e2cd34764c24755 (diff)
Changed TCallbackEventParameter::Parameter to TCallbackEventParameter::CallbackParameter
Add TActiveButton and TActiveCheckBox quickstart docs.
Diffstat (limited to 'framework/Web/UI')
-rw-r--r--framework/Web/UI/ActiveControls/TActiveCheckBox.php2
-rw-r--r--framework/Web/UI/ActiveControls/TActiveCustomValidator.php2
-rw-r--r--framework/Web/UI/ActiveControls/TActivePageAdapter.php10
-rw-r--r--framework/Web/UI/ActiveControls/TAutoComplete.php6
-rw-r--r--framework/Web/UI/ActiveControls/TInPlaceTextBox.php2
5 files changed, 11 insertions, 11 deletions
diff --git a/framework/Web/UI/ActiveControls/TActiveCheckBox.php b/framework/Web/UI/ActiveControls/TActiveCheckBox.php
index d6de63e3..7cf5c005 100644
--- a/framework/Web/UI/ActiveControls/TActiveCheckBox.php
+++ b/framework/Web/UI/ActiveControls/TActiveCheckBox.php
@@ -148,7 +148,7 @@ class TActiveCheckBox extends TCheckBox implements ICallbackEventHandler, IActiv
protected function getDefaultLabelID()
{
if($attributes=$this->getViewState('LabelAttributes',null))
- return $this->getLabelAttributes()->itemAt('id');
+ return TCheckBox::getLabelAttributes()->itemAt('id');
else
return $this->getClientID().'_label';
}
diff --git a/framework/Web/UI/ActiveControls/TActiveCustomValidator.php b/framework/Web/UI/ActiveControls/TActiveCustomValidator.php
index 7c4ab16b..80e594e2 100644
--- a/framework/Web/UI/ActiveControls/TActiveCustomValidator.php
+++ b/framework/Web/UI/ActiveControls/TActiveCustomValidator.php
@@ -85,7 +85,7 @@ class TActiveCustomValidator extends TCustomValidator
public function raiseCallbackEvent($param)
{
$this->_isCallback = true;
- $result = $this->onServerValidate($param->getParameter());
+ $result = $this->onServerValidate($param->getCallbackParameter());
$param->setData($result);
$this->onCallback($param);
}
diff --git a/framework/Web/UI/ActiveControls/TAutoComplete.php b/framework/Web/UI/ActiveControls/TAutoComplete.php
index dadb723a..080bb410 100644
--- a/framework/Web/UI/ActiveControls/TAutoComplete.php
+++ b/framework/Web/UI/ActiveControls/TAutoComplete.php
@@ -29,7 +29,7 @@ Prado::using('System.Web.UI.ActiveControls.TActiveTextBox');
*
* The list of suggestions should be set in the {@link onSuggestion OnSuggestion}
* event handler. The partial word to match the suggestion is in the
- * {@link TCallbackEventParameter::getParameter TCallbackEventParameter::Parameter}
+ * {@link TCallbackEventParameter::getCallbackParameter TCallbackEventParameter::CallbackParameter}
* property. The datasource of the TAutoComplete must be set using {@link setDataSource}
* method. This sets the datasource for the suggestions repeater, available through
* the {@link getSuggestions Suggestions} property. Header, footer templates and
@@ -41,7 +41,7 @@ Prado::using('System.Web.UI.ActiveControls.TActiveTextBox');
* <code>
* function autocomplete_suggestion($sender, $param)
* {
- * $token = $param->getParameter(); //the partial word to match
+ * $token = $param->getCallbackParameter(); //the partial word to match
* $sender->setDataSource($this->getSuggestionsFor($token)); //set suggestions
* $sender->dataBind();
* $sender->render($param->getNewWriter()); //sends suggestion back to browser.
@@ -138,7 +138,7 @@ class TAutoComplete extends TActiveTextBox implements INamingContainer
*/
public function raiseCallbackEvent($param)
{
- $token = $param->getParameter();
+ $token = $param->getCallbackParameter();
if(is_array($token) && count($token) == 2 && $token[1] === '__TAutoComplete_onSuggest__')
{
$parameter = new TCallbackEventParameter($this->getResponse(), $token[0]);
diff --git a/framework/Web/UI/ActiveControls/TInPlaceTextBox.php b/framework/Web/UI/ActiveControls/TInPlaceTextBox.php
index 5bfd9456..236e43d5 100644
--- a/framework/Web/UI/ActiveControls/TInPlaceTextBox.php
+++ b/framework/Web/UI/ActiveControls/TInPlaceTextBox.php
@@ -162,7 +162,7 @@ class TInPlaceTextBox extends TActiveTextBox
*/
public function onCallback($param)
{
- $action = $param->getParameter();
+ $action = $param->getCallbackParameter();
if(is_array($action) && $action[0] === '__InlineEditor_loadExternalText__')
{
$parameter = new TCallbackEventParameter($this->getResponse(), $action[1]);
diff --git a/framework/Web/UI/ActiveControls/TActivePageAdapter.php b/framework/Web/UI/ActiveControls/TActivePageAdapter.php
index c3ca8947..9274ddb7 100644
--- a/framework/Web/UI/ActiveControls/TActivePageAdapter.php
+++ b/framework/Web/UI/ActiveControls/TActivePageAdapter.php
@@ -242,7 +242,7 @@ class TActivePageAdapter extends TControlAdapter
* TCallbackEventParameter class.
*
* The TCallbackEventParameter provides the parameter passed during the callback
* requestion in the {@link getParameter Parameter} property. The
* callback response content (e.g. new HTML content) must be rendered
* using an THtmlWriter obtained from the {@link getNewWriter NewWriter}
* property, which returns a <b>NEW</b> instance of TCallbackResponseWriter.
@@ -253,7 +253,7 @@ class TActivePageAdapter extends TControlAdapter
* use the same writer instance for the panels to be rendered.
*
* The response data (i.e., passing results back to the client-side
- * callback handler function) can be set using {@link setData Data} property.
+ * callback handler function) can be set using {@link setResponseData ResponseData} property.
*
* @author Wei Zhuo <weizhuo[at]gamil[dot]com>
* @version $Id$
@@ -291,7 +291,7 @@ class TCallbackEventParameter extends TEventParameter
/**
* @return mixed callback request parameter.
*/
- public function getParameter()
+ public function getCallbackParameter()
{
return $this->_parameter;
}
@@ -299,7 +299,7 @@ class TCallbackEventParameter extends TEventParameter
/**
* @param mixed callback response data.
*/
- public function setData($value)
+ public function setResponesData($value)
{
$this->_response->getAdapter()->setResponseData($value);
}
@@ -307,7 +307,7 @@ class TCallbackEventParameter extends TEventParameter
/**
* @return mixed callback response data.
*/
- public function getData()
+ public function getResponesData()
{
return $this->_response->getAdapter()->getResponseData();
}
@@ -242,7 +242,7 @@ class TActivePageAdapter extends TControlAdapter
*
* The TCallbackEventParameter provides the parameter passed during the callback
- * requestion in the {@link getParameter Parameter} property. The
+ * requestion in the {@link getCallbackParameter CallbackParameter} property. The
* callback response content (e.g. new HTML content) must be rendered
* using an THtmlWriter obtained from the {@link getNewWriter NewWriter}